$LOAD_PATH.unshift(File.expand_path(File.dirname(__FILE__) + "/../lib"))
require 'roodi'
require 'rspec'
require 'coveralls'
Coveralls.wear!

